@@ -3,6 +3,8 @@
 // +build linux,cgo darwin,cgo freebsd,cgo windows
 // +build !race !windows
 
+// Package cmount implements a FUSE mounting system for rclone remotes.
+//
 // FIXME this doesn't work with the race detector under Windows either
 // hanging or producing lots of differences.
 
@@ -13,6 +15,7 @@ import (
 	"testing"
 
 	"github.com/rclone/rclone/fstest/testy"
+	"github.com/rclone/rclone/vfs/vfscommon"
 	"github.com/rclone/rclone/vfs/vfstest"
 )
 
@@ -21,5 +24,5 @@ func TestMount(t *testing.T) {
 	if runtime.GOOS == "darwin" {
 		testy.SkipUnreliable(t)
 	}
-	vfstest.RunTests(t, false, mount)
+	vfstest.RunTests(t, false, vfscommon.CacheModeOff, true, mount)
 }
