@@ -286,6 +286,9 @@ func (r *Run) MakeTestBinary() {
 	binaryName := r.BinaryName()
 	log.Printf("%s: Making test binary %q", r.Path, binaryName)
 	CmdLine := []string{"go", "test", "-c"}
+	if *race {
+		CmdLine = append(CmdLine, "-race")
+	}
 	if *dryRun {
 		log.Printf("Not executing: %v", CmdLine)
 		return
@@ -317,7 +320,7 @@ func (r *Run) RemoveTestBinary() {
 func (r *Run) Name() string {
 	ns := []string{
 		r.Backend,
-		strings.Replace(r.Path, "/", ".", -1),
+		strings.ReplaceAll(r.Path, "/", "."),
 		r.Remote,
 	}
 	if r.FastList {
@@ -325,7 +328,7 @@ func (r *Run) Name() string {
 	}
 	ns = append(ns, fmt.Sprintf("%d", r.Try))
 	s := strings.Join(ns, "-")
-	s = strings.Replace(s, ":", "", -1)
+	s = strings.ReplaceAll(s, ":", "")
 	return s
 }
 
